p.composite-header {
    color: rgb(120,120,120);
    font-weight: bold;
    display: inline-block;
    margin-bottom: 3px;
}

div.composite-header {
    display: block;
    padding-bottom: 10px;
}

div.composite-header div.info-inline{
    max-width: 165px;
}

div.first-subfield-info{
    display:block;
    padding-bottom: 20px; 
    padding-left: 130px; 
    margin-top: -15px;
}
div.first-subfield-info-inline{
    display:block;
    padding-bottom: 30px; 
    padding-left: 50px;
}
